@@ -42,8 +42,8 @@ time_order_histogram:\
 time_order_histogram_title: ELEM _S TTLS_TNAME_1TO25 _NL
 time_order_histogram_legend:\
     HIST_LEG_SCALE1 _S pfloat _S\
-    HIST_LEG_ORIG _S pint _S\
-    HIST_LEG_FIRSTCHAN _S pint _S\
+    HIST_LEG_ORIG fwint5 _S\
+    HIST_LEG_FIRSTCHAN fwint5 _S\
     HIST_LEG_ENTRIES1 _S pint _NL
 time_order_histogram_negative: TTLS_LABEL_5 _S pint _NL
 
@@ -84,7 +84,7 @@ sputtered_energy_histogram:\
 sputtered_energy_histogram_title: ELEM _S TTLS_ZNAME _NL
 sputtered_energy_histogram_legend:\
     HIST_LEG_SCALE3 float\
-    HIST_LEG_ORIG int _S\
+    HIST_LEG_ORIG fwint5 _S\
     HIST_LEG_FIRSTCHAN int _S\
     HIST_LEG_ENTRIES2 int _NL
 
@@ -104,9 +104,9 @@ binding_energy_histogram:\
 binding_energy_histogram_title: ELEM _S TTLS_QNAME _NL
 binding_energy_histogram_legend:\
     HIST_LEG_SCALE4 float\
-    HIST_LEG_ORIG int _S\
-    HIST_LEG_FIRSTCHAN int _S\
-    HIST_LEG_ENTRIES1 int _NL
+    HIST_LEG_ORIG fwint5 _S\
+    HIST_LEG_FIRSTCHAN fwint5 _S\
+    HIST_LEG_ENTRIES1 _S pint _NL
 
 HIST_LEG_SCALE1: "Histogram scale (fs)"
 HIST_LEG_SCALE2: "Inverse channel width (eV)"
@@ -121,6 +121,7 @@ HIST_LEG_ENTRIES2: "Total entries"
 grammer_join_list = [
         grammar,
         lark_common.grammar,
+        lark_common.grammar_fixedwidth_int,
         lark_common.grammar_elem,
         lark_common.grammar_ttls_hname, lark_common.grammar_ttls_tname,
         lark_common.grammar_ttls_nname, lark_common.grammar_ttls_gname, lark_common.grammar_ttls_zname,
@@ -138,7 +139,7 @@ class Context():
         self.mobj = []
 
 
-class Transformer(lark.Transformer):
+class Transformer(lark_common.Transformer):
     def __init__(self, context):
         super().__init__()
         self.context = context
@@ -150,12 +151,6 @@ class Transformer(lark.Transformer):
         self.current_number_header = None
         self.current_energy_header = None
 
-    def int(self, args):
-        return int(args[0])
-
-    def float(self, args):
-        return float(args[0])
-
     def cascade_summary_header(self, args):
         # Tree(cascade_summary_header,
         #    [Token(CASCADE_SUMMARY_HEADER_TOK1, 'Cascade Summary for'),
