@@ -66,7 +66,7 @@ seqx_replacement5: "*****Replacement sequences with large Miller indices encount
 seqx_individual_seq:\
     "All sequence directions are in external coordinates" _NL\
     ("Equivalent directions combined where possible" _NL)?\
-    ("Indeterminate directions are labelled < 0, 0, 0 >" _NL)?\
+    ("Indeterminate directions are labelled <0, 0, 0>" _NL)?\
     seqx_individual_seq_record+
     
 seqx_individual_seq_record:\
@@ -183,18 +183,18 @@ class Transformer(lark_common.Transformer):
 
     def seqx_replacement3_data_beg(self, args):
         return {
-                'Index': args[0],
+                'Index': f'{args[0]:d}',
                 'Mean': args[1],
                 'Variance': args[2],
                 'Skewness': args[3],
                 'Kurtosis': args[4],
                 'Std Dev': args[5],
                 'Error': args[6],
-                'Plus': False
                 }
 
     def seqx_replacement3_data_cont(self, args):
         return {
+                'Index': f'{args[0]:d}+',
                 'Index': args[0],
                 'Mean': args[1],
                 'Variance': args[2],
@@ -202,7 +202,6 @@ class Transformer(lark_common.Transformer):
                 'Kurtosis': args[4],
                 'Std Dev': args[5],
                 'Error': args[6],
-                'Plus': True
                 }
 
     def seqx_replacement4(self, args):
@@ -233,8 +232,9 @@ class Transformer(lark_common.Transformer):
     def seqx_individual_seq(self, args):
         '''"All sequence directions are in external coordinates" _NL\
         ("Equivalent directions combined where possible" _NL)?\
-        ("Indeterminate directions are labelled < 0, 0, 0 >" _NL)?\
+        ("Indeterminate directions are labelled <0, 0, 0>" _NL)?\
         seqx_individual_seq_record+'''
+        # todo re-organize seqx_individual_seq_record+ data
         self.context.mobj['Individual Sequence Statistics'] = args
 
     def seqx_individual_seq_record(self, args):
@@ -260,7 +260,7 @@ class Transformer(lark_common.Transformer):
     def seqx_individual_seq_maximum(self, args):
         '''seqx_individual_seq_maximum: "Maximum" (_S pfloat _S pfloat)+ _NL'''
         data = [{'Mean':a, 'Std Dev': b} for a, b in zip(args[0::2], args[1::2])]
-        return { 'Index': 'Maximum', 'data':data}
+        return { 'LengthIndex': 'Maximum', 'data':data}
 
     def seqx_individual_seq_data(self, args):
         return args[0]
@@ -269,13 +269,13 @@ class Transformer(lark_common.Transformer):
         '''seqx_individual_seq_data_beg: SIGNED_INT "  " /.+/ _NL'''
         index = int(args[0])
         data = self._seqx_individual_seq_data_parse(args[1])
-        return { 'Index': index, 'data':data, 'Plus': False}
+        return { 'LengthIndex': f'{index:d}', 'data':data}
 
     def seqx_individual_seq_data_cont(self, args):
-        '''seqx_individual_seq_data_beg: SIGNED_INT "+ " /.+/ _NL'''
+        '''seqx_individual_seq_data_cont: SIGNED_INT "+ " /.+/ _NL'''
         index = int(args[0])
         data = self._seqx_individual_seq_data_parse(args[1])
-        return { 'Index': index, 'data':data, 'Plus': True}
+        return { 'LengthIndex': f'{index:d}+', 'data':data}
 
     @staticmethod
     def _seqx_individual_seq_data_parse(text):
