@@ -13,10 +13,11 @@ class TestFinalSequex(unittest.TestCase):
     @parameterized.expand([
         '01.final_sequex.txt',
         '02.final_sequex.txt',
+        '03.final_sequex.txt',
         ])
     def test_final_sequex(self, filename):
         p = self.current_dir / 'final_sequex_examples'/ filename
         # print(p)
-        # final_sequex.parse(text)
         with p.open('rt') as f:
             result = final_sequex.parse(f.read())
+            # print(result)
